"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const watch_1 = require("./watch");
const path_1 = __importDefault(require("path"));
const sinon = __importStar(require("sinon"));
const vitest_1 = require("vitest");
const zx_1 = require("zx");
zx_1.$.verbose = false;
const spyRoarr = () => {
    const { ROARR_LOG } = process.env;
    if (ROARR_LOG !== 'true') {
        throw new Error('ROARR_LOG must be set to "true"');
    }
    const messages = [];
    globalThis.ROARR.write = (message) => {
        const payload = JSON.parse(message);
        messages.push(payload);
    };
    return {
        getMessages: () => {
            return messages;
        },
    };
};
(0, vitest_1.beforeEach)(async () => {
    await (0, zx_1.$) `rm -fr .fixtures`;
    await (0, zx_1.$) `mkdir .fixtures`;
    await (0, zx_1.$) `touch .fixtures/foo`;
});
(0, vitest_1.afterEach)(async () => {
    await (0, zx_1.$) `rm -fr .fixtures`;
});
(0, vitest_1.it)('detects file change', async () => {
    const abortController = new AbortController();
    const onChange = sinon.stub().callsFake(async () => {
        abortController.abort();
    });
    await (0, watch_1.watch)({
        abortSignal: abortController.signal,
        onReady: async () => {
            await (0, zx_1.$) `touch .fixtures/foo`;
        },
        project: path_1.default.resolve(__dirname, '../.fixtures'),
        triggers: [
            {
                expression: ['match', 'foo', 'basename'],
                initialRun: false,
                name: 'foo',
                onChange,
            },
        ],
    });
    (0, vitest_1.expect)(onChange.called).toBe(true);
});
// https://github.com/gajus/turbowatch/issues/17
(0, vitest_1.it)('does not log every file change', async () => {
    const abortController = new AbortController();
    const onChange = sinon.stub().callsFake(async () => {
        abortController.abort();
    });
    const roarrSpy = spyRoarr();
    await (0, watch_1.watch)({
        abortSignal: abortController.signal,
        onReady: async () => {
            for (let index = 0; index++ < 100;) {
                await (0, zx_1.$) `touch .fixtures/foo`;
            }
        },
        project: path_1.default.resolve(__dirname, '../.fixtures'),
        triggers: [
            {
                expression: ['match', 'foo', 'basename'],
                initialRun: false,
                name: 'foo',
                onChange,
            },
        ],
    });
    (0, vitest_1.expect)(onChange.called).toBe(true);
    (0, vitest_1.expect)(roarrSpy.getMessages().length < 20).toBe(true);
});
//# sourceMappingURL=watch.test.js.map